@@ -269,62 +269,79 @@ popTime <- function(data, time, event, censored.indicator,
 #' @importFrom ggplot2 margin element_blank rel %+replace%
 theme_cb <- function(font_size = 14, font_family = "", line_size = 0.5,
                      rel_small = 12/14, rel_tiny = 11/14, rel_large = 16/14) {
-  half_line <- 0.5 * font_size
-  small_size <- rel_small * font_size
-  ggplot2::theme_grey(base_size = font_size, base_family = font_family) %+replace%
-    theme(line = element_line(color = "black", size = line_size,
-                              linetype = 1, lineend = "butt"), rect = element_rect(fill = NA,
-                                                                                   color = NA, size = line_size, linetype = 1), text = element_text(family = font_family,
-                                                                                                                                                    face = "plain", color = "black", size = font_size,
-                                                                                                                                                    hjust = 0.5, vjust = 0.5, angle = 0, lineheight = 0.9,
-                                                                                                                                                    margin = margin(), debug = FALSE), axis.line = element_line(color = "black",
-                                                                                                                                                                                                                size = line_size, lineend = "square"), axis.line.x = NULL,
-          axis.line.y = NULL, axis.text = element_text(color = "black",
-                                                       size = small_size), axis.text.x = element_text(margin = margin(t = 0.25 * small_size),
-                                                                                                      vjust = 1), axis.text.x.top = element_text(margin = margin(b = 0.25 * small_size),
-                                                                                                                                                 vjust = 0), axis.text.y = element_text(margin = margin(r = 0.25 * small_size),
-                                                                                                                                                                                        hjust = 1), axis.text.y.right = element_text(margin = margin(l = 0.25 * small_size),
-                                                                                                                                                                                                                                     hjust = 0), axis.ticks = element_line(color = "black",
-                                                                                                                                                                                                                                                                           size = line_size), axis.ticks.length = unit(0.5 * half_line,
-                                                                                                                                                                                                                                                                                                                       "pt"), axis.title.x = element_text(margin = margin(t = 0.5 * half_line),
-                                                                                                                                                                                                                                                                                                                                                          vjust = 1), axis.title.x.top = element_text(margin = margin(b = 0.5 * half_line),
-                                                                                                                                                                                                                                                                                                                                                                                                      vjust = 0), axis.title.y = element_text(angle = 90,
-                                                                                                                                                                                                                                                                                                                                                                                                                                              margin = margin(r = 0.5 * half_line),
-                                                                                                                                                                                                                                                                                                                                                                                                                                              vjust = 1),
-          axis.title.y.right = element_text(angle = -90, margin = margin(l = 0.5 * half_line),
-                                            vjust = 0), legend.background = element_blank(),
-          legend.spacing = unit(font_size, "pt"), legend.spacing.x = NULL,
-          legend.spacing.y = NULL, legend.margin = margin(0,
-                                                          0, 0, 0), legend.key = element_blank(), legend.key.size = unit(1.1 *
-                                                                                                                           font_size, "pt"), legend.key.height = NULL,
-          legend.key.width = NULL, legend.text = element_text(size = rel(rel_small)),
-          legend.text.align = NULL, legend.title = element_text(hjust = 0),
-          legend.title.align = NULL, legend.position = "right",
-          legend.direction = NULL, legend.justification = c("left",
-                                                            "center"), legend.box = NULL, legend.box.margin = margin(0,
-                                                                                                                     0, 0, 0), legend.box.background = element_blank(),
-          legend.box.spacing = unit(font_size, "pt"), panel.background = element_blank(),
-          panel.border = element_blank(), panel.grid = element_blank(),
-          panel.grid.major = NULL, panel.grid.minor = NULL,
-          panel.grid.major.x = NULL, panel.grid.major.y = NULL,
-          panel.grid.minor.x = NULL, panel.grid.minor.y = NULL,
-          panel.spacing = unit(half_line, "pt"), panel.spacing.x = NULL,
-          panel.spacing.y = NULL, panel.ontop = FALSE, strip.background = element_rect(fill = "grey80"),
-          strip.text = element_text(size = rel(rel_small),
-                                    margin = margin(0.5 * half_line, 0.5 * half_line, 0.5 * half_line,
-                                                    0.5 * half_line)), strip.text.x = NULL, strip.text.y = element_text(angle = -90),
-          strip.placement = "inside", strip.placement.x = NULL,
-          strip.placement.y = NULL, strip.switch.pad.grid = unit(0.5 * half_line,
-                                                                 "pt"), strip.switch.pad.wrap = unit(0.5 * half_line,
-                                                                                                     "pt"), plot.background = element_blank(), plot.title = element_text(face = "bold",
-                                                                                                                                                                         size = rel(rel_large), hjust = 0, vjust = 1,
-                                                                                                                                                                         margin = margin(b = half_line)), plot.subtitle = element_text(size = rel(rel_small),
-                                                                                                                                                                                                                                       hjust = 0, vjust = 1, margin = margin(b = half_line)),
-          plot.caption = element_text(size = rel(rel_tiny),
-                                      hjust = 1, vjust = 1, margin = margin(t = half_line)),
-          plot.tag = element_text(face = "bold", hjust = 0,
-                                  vjust = 0.7), plot.tag.position = c(0, 1), plot.margin = margin(half_line,
-                                                                                                  half_line, half_line, half_line), complete = TRUE)
+    half_line <- 0.5 * font_size
+    small_size <- rel_small * font_size
+    ggplot2::theme_grey(base_size = font_size, base_family = font_family) %+replace%
+        theme(line = element_line(color = "black", linewidth = line_size,
+                                  linetype = 1, lineend = "butt"),
+              rect = element_rect(fill = NA, color = NA, linewidth = line_size,
+                                  linetype = 1),
+              text = element_text(family = font_family,
+                                  face = "plain", color = "black", size = font_size,
+                                  hjust = 0.5, vjust = 0.5, angle = 0, lineheight = 0.9,
+                                  margin = margin(), debug = FALSE),
+              axis.line = element_line(color = "black",
+                                       linewidth = line_size,
+                                       lineend = "square"),
+              axis.line.x = NULL,
+              axis.line.y = NULL,
+              axis.text = element_text(color = "black", size = small_size),
+              axis.text.x = element_text(margin = margin(t = 0.25 * small_size),
+                                         vjust = 1),
+              axis.text.x.top = element_text(margin = margin(b = 0.25 * small_size),
+                                             vjust = 0),
+              axis.text.y = element_text(margin = margin(r = 0.25 * small_size),
+                                         hjust = 1),
+              axis.text.y.right = element_text(margin = margin(l = 0.25 * small_size),
+                                               hjust = 0),
+              axis.ticks = element_line(color = "black", linewidth = line_size),
+              axis.ticks.length = unit(0.5 * half_line, "pt"),
+              axis.title.x = element_text(margin = margin(t = 0.5 * half_line),
+                                          vjust = 1),
+              axis.title.x.top = element_text(margin = margin(b = 0.5 * half_line),
+                                              vjust = 0),
+              axis.title.y = element_text(angle = 90,
+                                          margin = margin(r = 0.5 * half_line),
+                                          vjust = 1),
+              axis.title.y.right = element_text(angle = -90, margin = margin(l = 0.5 * half_line),
+                                                vjust = 0), legend.background = element_blank(),
+              legend.spacing = unit(font_size, "pt"), legend.spacing.x = NULL,
+              legend.spacing.y = NULL,
+              legend.margin = margin(0, 0, 0, 0),
+              legend.key = element_blank(),
+              legend.key.size = unit(1.1 * font_size, "pt"), legend.key.height = NULL,
+              legend.key.width = NULL, legend.text = element_text(size = rel(rel_small)),
+              legend.text.align = NULL, legend.title = element_text(hjust = 0),
+              legend.title.align = NULL, legend.position = "right",
+              legend.direction = NULL,
+              legend.justification = c("left", "center"),
+              legend.box = NULL,
+              legend.box.margin = margin(0, 0, 0, 0), legend.box.background = element_blank(),
+              legend.box.spacing = unit(font_size, "pt"), panel.background = element_blank(),
+              panel.border = element_blank(), panel.grid = element_blank(),
+              panel.grid.major = NULL, panel.grid.minor = NULL,
+              panel.grid.major.x = NULL, panel.grid.major.y = NULL,
+              panel.grid.minor.x = NULL, panel.grid.minor.y = NULL,
+              panel.spacing = unit(half_line, "pt"), panel.spacing.x = NULL,
+              panel.spacing.y = NULL, panel.ontop = FALSE,
+              strip.background = element_rect(fill = "grey80"),
+              strip.text = element_text(size = rel(rel_small),
+                                        margin = margin(0.5 * half_line, 0.5 * half_line, 0.5 * half_line,
+                                                        0.5 * half_line)),
+              strip.text.x = NULL, strip.text.y = element_text(angle = -90),
+              strip.placement = "inside", strip.placement.x = NULL,
+              strip.placement.y = NULL,
+              strip.switch.pad.grid = unit(0.5 * half_line, "pt"),
+              strip.switch.pad.wrap = unit(0.5 * half_line, "pt"),
+              plot.background = element_blank(),
+              plot.title = element_text(face = "bold", size = rel(rel_large), hjust = 0, vjust = 1, margin = margin(b = half_line)),
+              plot.subtitle = element_text(size = rel(rel_small), hjust = 0, vjust = 1, margin = margin(b = half_line)),
+              plot.caption = element_text(size = rel(rel_tiny),
+                                          hjust = 1, vjust = 1, margin = margin(t = half_line)),
+              plot.tag = element_text(face = "bold", hjust = 0,
+                                      vjust = 0.7), plot.tag.position = c(0, 1),
+              plot.margin = margin(half_line, half_line, half_line, half_line),
+              complete = TRUE)
 }
 
 
@@ -341,6 +358,7 @@ panelBorder <- function(color = "grey85", size = 1, linetype = 1,
   }
   theme(panel.border = element_rect(
     color = color, fill = NA,
-    linetype = linetype, size = size
+    linetype = linetype,
+    linewidth = size
   ))
 }
