@@ -1,3 +1,10 @@
+context("plotHazard")
+set.seed(12345)
+
+# CRAN skip atlas check fix
+testthat::skip_if(grepl(pattern = "atlas", sessionInfo()$BLAS,
+                        ignore.case = TRUE))
+
 skip_if_not_installed("glmnet")
 skip_if_not_installed("mgcv")
 skip_if_not_installed("gbm")
