@@ -1,3 +1,10 @@
+context("popTime methods")
+set.seed(12345)
+
+# CRAN skip atlas check fix
+testthat::skip_if(grepl(pattern = "atlas", sessionInfo()$BLAS,
+                        ignore.case = TRUE))
+
 nobs <- 500
 
 # simulation parameters
